@@ -346,7 +346,8 @@ class VectorAwkward:
     def __getitem__(
         self, where: typing.Any
     ) -> typing.Optional[typing.Union[float, ak.Array, ak.Record]]:
-        return super().__getitem__(where)  # type: ignore
+        # "__getitem__" undefined in superclass
+        return super().__getitem__(where)  # type: ignore[misc]
 
     def _wrap_result(
         self,
@@ -714,7 +715,7 @@ class MomentumAwkward4D(LorentzMomentum, VectorAwkward4D):
 # ak.Array and ak.Record subclasses ###########################################
 
 
-class VectorArray2D(VectorAwkward2D, ak.Array):
+class VectorArray2D(VectorAwkward2D, ak.Array):  # type: ignore[misc]
     def allclose(
         self,
         other: VectorProtocol,
@@ -731,14 +732,14 @@ class VectorArray2D(VectorAwkward2D, ak.Array):
 behavior["*", "Vector2D"] = VectorArray2D
 
 
-class VectorRecord2D(VectorAwkward2D, ak.Record):
+class VectorRecord2D(VectorAwkward2D, ak.Record):  # type: ignore[misc]
     pass
 
 
 behavior["Vector2D"] = VectorRecord2D
 
 
-class VectorArray3D(VectorAwkward3D, ak.Array):
+class VectorArray3D(VectorAwkward3D, ak.Array):  # type: ignore[misc]
     def allclose(
         self,
         other: VectorProtocol,
@@ -755,14 +756,14 @@ class VectorArray3D(VectorAwkward3D, ak.Array):
 behavior["*", "Vector3D"] = VectorArray3D
 
 
-class VectorRecord3D(VectorAwkward3D, ak.Record):
+class VectorRecord3D(VectorAwkward3D, ak.Record):  # type: ignore[misc]
     pass
 
 
 behavior["Vector3D"] = VectorRecord3D
 
 
-class VectorArray4D(VectorAwkward4D, ak.Array):
+class VectorArray4D(VectorAwkward4D, ak.Array):  # type: ignore[misc]
     def allclose(
         self,
         other: VectorProtocol,
@@ -779,14 +780,14 @@ class VectorArray4D(VectorAwkward4D, ak.Array):
 behavior["*", "Vector4D"] = VectorArray4D
 
 
-class VectorRecord4D(VectorAwkward4D, ak.Record):
+class VectorRecord4D(VectorAwkward4D, ak.Record):  # type: ignore[misc]
     pass
 
 
 behavior["Vector4D"] = VectorRecord4D
 
 
-class MomentumArray2D(MomentumAwkward2D, ak.Array):
+class MomentumArray2D(MomentumAwkward2D, ak.Array):  # type: ignore[misc]
     def allclose(
         self,
         other: VectorProtocol,
@@ -800,14 +801,14 @@ class MomentumArray2D(MomentumAwkward2D, ak.Array):
 behavior["*", "Momentum2D"] = MomentumArray2D
 
 
-class MomentumRecord2D(MomentumAwkward2D, ak.Record):
+class MomentumRecord2D(MomentumAwkward2D, ak.Record):  # type: ignore[misc]
     pass
 
 
 behavior["Momentum2D"] = MomentumRecord2D
 
 
-class MomentumArray3D(MomentumAwkward3D, ak.Array):
+class MomentumArray3D(MomentumAwkward3D, ak.Array):  # type: ignore[misc]
     def allclose(
         self,
         other: VectorProtocol,
@@ -821,14 +822,14 @@ class MomentumArray3D(MomentumAwkward3D, ak.Array):
 behavior["*", "Momentum3D"] = MomentumArray3D
 
 
-class MomentumRecord3D(MomentumAwkward3D, ak.Record):
+class MomentumRecord3D(MomentumAwkward3D, ak.Record):  # type: ignore[misc]
     pass
 
 
 behavior["Momentum3D"] = MomentumRecord3D
 
 
-class MomentumArray4D(MomentumAwkward4D, ak.Array):
+class MomentumArray4D(MomentumAwkward4D, ak.Array):  # type: ignore[misc]
     def allclose(
         self,
         other: VectorProtocol,
@@ -842,7 +843,7 @@ class MomentumArray4D(MomentumAwkward4D, ak.Array):
 behavior["*", "Momentum4D"] = MomentumArray4D
 
 
-class MomentumRecord4D(MomentumAwkward4D, ak.Record):
+class MomentumRecord4D(MomentumAwkward4D, ak.Record):  # type: ignore[misc]
     pass
 
 
@@ -864,37 +865,37 @@ behavior[numpy.square, "Momentum2D"] = lambda v: v.rho2
 behavior[numpy.square, "Momentum3D"] = lambda v: v.mag2
 behavior[numpy.square, "Momentum4D"] = lambda v: v.tau2
 
-behavior[numpy.sqrt, "Vector2D"] = lambda v: v.rho2 ** 0.25
-behavior[numpy.sqrt, "Vector3D"] = lambda v: v.mag2 ** 0.25
-behavior[numpy.sqrt, "Vector4D"] = lambda v: v.tau2 ** 0.25
-behavior[numpy.sqrt, "Momentum2D"] = lambda v: v.rho2 ** 0.25
-behavior[numpy.sqrt, "Momentum3D"] = lambda v: v.mag2 ** 0.25
-behavior[numpy.sqrt, "Momentum4D"] = lambda v: v.tau2 ** 0.25
+behavior[numpy.sqrt, "Vector2D"] = lambda v: v.rho2**0.25
+behavior[numpy.sqrt, "Vector3D"] = lambda v: v.mag2**0.25
+behavior[numpy.sqrt, "Vector4D"] = lambda v: v.tau2**0.25
+behavior[numpy.sqrt, "Momentum2D"] = lambda v: v.rho2**0.25
+behavior[numpy.sqrt, "Momentum3D"] = lambda v: v.mag2**0.25
+behavior[numpy.sqrt, "Momentum4D"] = lambda v: v.tau2**0.25
 
-behavior[numpy.cbrt, "Vector2D"] = lambda v: v.rho2 ** 0.16666666666666666
-behavior[numpy.cbrt, "Vector3D"] = lambda v: v.mag2 ** 0.16666666666666666
-behavior[numpy.cbrt, "Vector4D"] = lambda v: v.tau2 ** 0.16666666666666666
-behavior[numpy.cbrt, "Momentum2D"] = lambda v: v.rho2 ** 0.16666666666666666
-behavior[numpy.cbrt, "Momentum3D"] = lambda v: v.mag2 ** 0.16666666666666666
-behavior[numpy.cbrt, "Momentum4D"] = lambda v: v.tau2 ** 0.16666666666666666
+behavior[numpy.cbrt, "Vector2D"] = lambda v: v.rho2**0.16666666666666666
+behavior[numpy.cbrt, "Vector3D"] = lambda v: v.mag2**0.16666666666666666
+behavior[numpy.cbrt, "Vector4D"] = lambda v: v.tau2**0.16666666666666666
+behavior[numpy.cbrt, "Momentum2D"] = lambda v: v.rho2**0.16666666666666666
+behavior[numpy.cbrt, "Momentum3D"] = lambda v: v.mag2**0.16666666666666666
+behavior[numpy.cbrt, "Momentum4D"] = lambda v: v.tau2**0.16666666666666666
 
 behavior[numpy.power, "Vector2D", numbers.Real] = (
-    lambda v, expo: v.rho2 if expo == 2 else v.rho ** expo
+    lambda v, expo: v.rho2 if expo == 2 else v.rho**expo
 )
 behavior[numpy.power, "Vector3D", numbers.Real] = (
-    lambda v, expo: v.mag2 if expo == 2 else v.mag ** expo
+    lambda v, expo: v.mag2 if expo == 2 else v.mag**expo
 )
 behavior[numpy.power, "Vector4D", numbers.Real] = (
-    lambda v, expo: v.tau2 if expo == 2 else v.tau ** expo
+    lambda v, expo: v.tau2 if expo == 2 else v.tau**expo
 )
 behavior[numpy.power, "Momentum2D", numbers.Real] = (
-    lambda v, expo: v.rho2 if expo == 2 else v.rho ** expo
+    lambda v, expo: v.rho2 if expo == 2 else v.rho**expo
 )
 behavior[numpy.power, "Momentum3D", numbers.Real] = (
-    lambda v, expo: v.mag2 if expo == 2 else v.mag ** expo
+    lambda v, expo: v.mag2 if expo == 2 else v.mag**expo
 )
 behavior[numpy.power, "Momentum4D", numbers.Real] = (
-    lambda v, expo: v.tau2 if expo == 2 else v.tau ** expo
+    lambda v, expo: v.tau2 if expo == 2 else v.tau**expo
 )
 
 behavior["__cast__", VectorNumpy2D] = lambda v: vector.Array(v)
@@ -1012,6 +1013,19 @@ MomentumRecord4D.GenericClass = VectorRecord4D
 # implementation of behaviors in Numba ########################################
 
 
+def _arraytype_of(awkwardtype: typing.Any, component: str) -> typing.Any:
+    import numba
+
+    if isinstance(awkwardtype, ak._connect._numba.layout.NumpyArrayType):
+        return awkwardtype.arraytype
+    elif isinstance(awkwardtype, ak._connect._numba.layout.IndexedArrayType):
+        return _arraytype_of(awkwardtype.contenttype, component)
+    else:
+        raise numba.TypingError(
+            f"vector components like {repr(component)} must be NumpyArrayType, not {awkwardtype}"
+        )
+
+
 def _aztype_of(recordarraytype: typing.Any, is_momentum: bool) -> typing.Any:
     import numba
 
@@ -1061,13 +1075,13 @@ def _aztype_of(recordarraytype: typing.Any, is_momentum: bool) -> typing.Any:
         phi_index = None
 
     if x_index is not None and y_index is not None:
-        coord1 = recordarraytype.contenttypes[x_index].arraytype.dtype
-        coord2 = recordarraytype.contenttypes[y_index].arraytype.dtype
+        coord1 = _arraytype_of(recordarraytype.contenttypes[x_index], "x").dtype
+        coord2 = _arraytype_of(recordarraytype.contenttypes[y_index], "y").dtype
         cls = AzimuthalObjectXY
 
     elif rho_index is not None and phi_index is not None:
-        coord1 = recordarraytype.contenttypes[rho_index].arraytype.dtype
-        coord2 = recordarraytype.contenttypes[phi_index].arraytype.dtype
+        coord1 = _arraytype_of(recordarraytype.contenttypes[rho_index], "rho").dtype
+        coord2 = _arraytype_of(recordarraytype.contenttypes[phi_index], "phi").dtype
         cls = AzimuthalObjectRhoPhi
 
     elif is_momentum:
@@ -1116,15 +1130,15 @@ def _ltype_of(recordarraytype: typing.Any, is_momentum: bool) -> typing.Any:
         eta_index = None
 
     if z_index is not None:
-        coord1 = recordarraytype.contenttypes[z_index].arraytype.dtype
+        coord1 = _arraytype_of(recordarraytype.contenttypes[z_index], "z").dtype
         cls = LongitudinalObjectZ
 
     elif theta_index is not None:
-        coord1 = recordarraytype.contenttypes[theta_index].arraytype.dtype
+        coord1 = _arraytype_of(recordarraytype.contenttypes[theta_index], "theta").dtype
         cls = LongitudinalObjectTheta
 
     elif eta_index is not None:
-        coord1 = recordarraytype.contenttypes[eta_index].arraytype.dtype
+        coord1 = _arraytype_of(recordarraytype.contenttypes[eta_index], "eta").dtype
         cls = LongitudinalObjectEta
 
     elif is_momentum:
@@ -1193,11 +1207,11 @@ def _ttype_of(recordarraytype: typing.Any, is_momentum: bool) -> typing.Any:
             tau_index = None
 
     if t_index is not None:
-        coord1 = recordarraytype.contenttypes[t_index].arraytype.dtype
+        coord1 = _arraytype_of(recordarraytype.contenttypes[t_index], "t").dtype
         cls = TemporalObjectT
 
     elif tau_index is not None:
-        coord1 = recordarraytype.contenttypes[tau_index].arraytype.dtype
+        coord1 = _arraytype_of(recordarraytype.contenttypes[tau_index], "tau").dtype
         cls = TemporalObjectTau
 
     elif is_momentum:
@@ -1216,8 +1230,8 @@ def _ttype_of(recordarraytype: typing.Any, is_momentum: bool) -> typing.Any:
 def _numba_typer_Vector2D(viewtype: typing.Any) -> typing.Any:
     import vector._backends.numba_object
 
-    # These clearly exist, a bug somewhere, but ignoring them for now
-    return vector._backends.numba_object.VectorObject2DType(  # type: ignore
+    # These exist, but the file is type ignored, so can't be found
+    return vector._backends.numba_object.VectorObject2DType(  # type: ignore[attr-defined]
         _aztype_of(viewtype.arrayviewtype.type, False)
     )
 
@@ -1225,7 +1239,7 @@ def _numba_typer_Vector2D(viewtype: typing.Any) -> typing.Any:
 def _numba_typer_Vector3D(viewtype: typing.Any) -> typing.Any:
     import vector._backends.numba_object
 
-    return vector._backends.numba_object.VectorObject3DType(  # type: ignore
+    return vector._backends.numba_object.VectorObject3DType(  # type: ignore[attr-defined]
         _aztype_of(viewtype.arrayviewtype.type, False),
         _ltype_of(viewtype.arrayviewtype.type, False),
     )
@@ -1234,7 +1248,7 @@ def _numba_typer_Vector3D(viewtype: typing.Any) -> typing.Any:
 def _numba_typer_Vector4D(viewtype: typing.Any) -> typing.Any:
     import vector._backends.numba_object
 
-    return vector._backends.numba_object.VectorObject4DType(  # type: ignore
+    return vector._backends.numba_object.VectorObject4DType(  # type: ignore[attr-defined]
         _aztype_of(viewtype.arrayviewtype.type, False),
         _ltype_of(viewtype.arrayviewtype.type, False),
         _ttype_of(viewtype.arrayviewtype.type, False),
@@ -1244,7 +1258,7 @@ def _numba_typer_Vector4D(viewtype: typing.Any) -> typing.Any:
 def _numba_typer_Momentum2D(viewtype: typing.Any) -> typing.Any:
     import vector._backends.numba_object
 
-    return vector._backends.numba_object.MomentumObject2DType(  # type: ignore
+    return vector._backends.numba_object.MomentumObject2DType(  # type: ignore[attr-defined]
         _aztype_of(viewtype.arrayviewtype.type, True)
     )
 
@@ -1252,7 +1266,7 @@ def _numba_typer_Momentum2D(viewtype: typing.Any) -> typing.Any:
 def _numba_typer_Momentum3D(viewtype: typing.Any) -> typing.Any:
     import vector._backends.numba_object
 
-    return vector._backends.numba_object.MomentumObject3DType(  # type: ignore
+    return vector._backends.numba_object.MomentumObject3DType(  # type: ignore[attr-defined]
         _aztype_of(viewtype.arrayviewtype.type, True),
         _ltype_of(viewtype.arrayviewtype.type, True),
     )
@@ -1261,7 +1275,7 @@ def _numba_typer_Momentum3D(viewtype: typing.Any) -> typing.Any:
 def _numba_typer_Momentum4D(viewtype: typing.Any) -> typing.Any:
     import vector._backends.numba_object
 
-    return vector._backends.numba_object.MomentumObject4DType(  # type: ignore
+    return vector._backends.numba_object.MomentumObject4DType(  # type: ignore[attr-defined]
         _aztype_of(viewtype.arrayviewtype.type, True),
         _ltype_of(viewtype.arrayviewtype.type, True),
         _ttype_of(viewtype.arrayviewtype.type, True),
@@ -1271,7 +1285,7 @@ def _numba_typer_Momentum4D(viewtype: typing.Any) -> typing.Any:
 def _numba_lower(
     context: typing.Any, builder: typing.Any, sig: typing.Any, args: typing.Any
 ) -> typing.Any:
-    from vector._backends.numba_object import (  # type: ignore
+    from vector._backends.numba_object import (  # type: ignore[attr-defined]
         _awkward_numba_E,
         _awkward_numba_e,
         _awkward_numba_energy,
